Learn R Programming

vhcub (version 1.0.0)

fasta.read: Read fasta formate and convert it to data frame

Description

Read fasta formate and convert it to data frame

Usage

fasta.read(virus.fasta,host.fasta)

Arguments

virus.fasta

directory path to the virus fasta file.

host.fasta

directory path to the host fasta file.

Value

A list with two data frames.

Examples

Run this code
# NOT RUN {
fasta <- fasta.read("virus.fasta", "host.fasta")
fasta.v <- fasta[[1]]
fasta.h <- fasta[[2]]
# }

Run the code above in your browser using DataLab